import * as _nuxt_schema from '@nuxt/schema';
import { PresetOptions } from '@anu-vue/preset-theme-default';
import { PresetAnuOptions, PluginOptions } from 'anu-vue';
import { PartialDeep } from 'type-fest';

/** Nuxt Module Options */
interface ModuleOptions {
    /**
     * Import Anu Preset Theme Default
     * When enabled, it will automatically set up the default theme preset for Anu and Uno.
     *
     * @default true
     */
    presetThemeDefault?: PresetOptions | boolean;
    /**
     * Options for Anu Preset
     */
    presetAnuOptions?: PresetAnuOptions;
    /**
     * Anu Vue Initial Theme | Source npm pkg: `anu-vue`
     * You can pass in your own initial theme to override the default theme.
     *
     * @remarks
     * The default theme for `initialTheme` is `light`. You can also make it `dark` by setting it to `dark`.
     *
     * @default 'light'
     */
    initialTheme?: PluginOptions['initialTheme'];
    /**
     * Anu Vue Themes | Source npm pkg: `anu-vue`
     * You can pass in your own themes to override the default themes.
     *
     * @remarks
     * The default themes for `light` and `dark` are:
     *
     * ```ts
     * {
     *   light: {
     *     class: '',
     *     colors: {
     *       primary: '265, 97.7%, 66.3%',
     *       success: '94.5, 100%, 39.6%',
     *       info: '200.1, 100%, 54.3%',
     *       warning: '42.4, 100%, 50%',
     *       danger: '358.3, 100%, 64.9%',
     *     },
     *     cssVars: {},
     *   },
     *   dark: {
     *     class: 'dark',
     *     colors: {
     *       primary: '261, 73%, 66.3%',
     *       success: '94.5, 73%, 39.6%',
     *       info: '200.1, 73%, 54.3%',
     *       warning: '42.4, 73%, 50%',
     *       danger: '358.3, 73%, 64.9%',
     *     },
     *     cssVars: {},
     *   },
     * }
     * ```
     */
    themes?: PartialDeep<PluginOptions['themes']>;
    componentAliases?: PluginOptions['componentAliases'];
    propsDefaults?: PluginOptions['propsDefaults'];
}
declare const _default: _nuxt_schema.NuxtModule<ModuleOptions>;

declare module '@nuxt/schema' {
    interface NuxtConfig {
        anu?: ModuleOptions;
    }
    interface NuxtOptions {
        anu?: ModuleOptions;
    }
}

export { ModuleOptions, _default as default };
